Version 0.3.1 (2015-10-06)
==========================

* Read the docs documentation
* Handle time stamp conversion of the new Device.lastSyncTime field
* MisfitNotification.Message is now a list of MisfitMessage objects

Version 0.2.0 (2015-01-31)
==========================

* Better error handling when authorizing on the local CherryPy server
* Show --help option when no arguments are supplied to the misfit command
* Fix a bug preventing local misfit authorization from working with command-line browsers

Version 0.1.1 (2014-12-22)
==========================

* Support for verifying signed SubscriptionConfirmation messages

Version 0.1.0 (2014-12-19)
==========================

* Misfit classes with data attributes
* Support for Python 3.x and PyPy
* Notification support (including SNS signature verification)
* MisfitAuth class to handle OAuth2
* Many squished bugs

Version 0.0.1 (2014-12-05)
==========================

* Initial release
